@@ -36,29 +36,21 @@ L<Mail::SRS>
 sub compile {
 	my ($self, $sendhost, $senduser) = @_;
 
-	if ($senduser =~ m/^\Q$SRSTAG$SRSSEP\E/io) {
+	if ($senduser =~ s/^$SRS0RE//io) {
 		# We just do the split because this was hashed with someone else's
 		# secret key and we can't check it.
-		# SRSTAG, hash, timestamp, host, user
-		my (undef, undef, undef, $oldhost, $olduser) =
-						split(qr/\Q$SRSSEP\E/, $senduser, 5);
-		# We should do this sanity check. After all, it might NOT be
-		# an SRS address, unlikely though that is. We are in the presence
-		# of malicious agents. We can check more rigorously than this...
-		if (defined $oldhost and defined $olduser) {
-			$sendhost = $oldhost;
-			$senduser = $olduser;
-		}
+		# hash, timestamp, host, user
+		(undef, undef, $sendhost, $senduser) =
+						split(qr/\Q$SRSSEP\E/, $senduser, 4);
+		# We should do a sanity check. After all, it might NOT be
+		# an SRS address, unlikely though that is. We are in the
+		# presence of malicious agents.
 	}
-	elsif ($senduser =~ m/^\W$SRSWRAP$SRSSEP\E/io) {
+	elsif ($senduser =~ s/$SRS1RE//io) {
 		# Introduce compatibility with the guarded format?
-		# SRS1, SRSHOST, hash, timestamp, host, user
-		my (undef, undef, undef, undef, $oldhost, $olduser) =
+		# SRSHOST, hash, timestamp, host, user
+		(undef, undef, undef, $sendhost, $senduser) =
 						split(qr/\Q$SRSSEP\E/, $senduser, 6);
-		if (defined $oldhost and defined $olduser) {
-			$sendhost = $oldhost;
-			$senduser = $olduser;
-		}
 	}
 
 	my $timestamp = $self->timestamp_create();
@@ -70,21 +62,21 @@ sub compile {
 	# Note that there are 5 fields here and that sendhost may
 	# not contain a + sign. Therefore, we do not need to escape
 	# + signs anywhere in order to reverse this transformation.
-	return join($SRSSEP,
-					$SRSTAG, $hash, $timestamp, $sendhost, $senduser);
+	return $SRS0TAG . $self->separator .
+			join($SRSSEP, $hash, $timestamp, $sendhost, $senduser);
 }
 
 sub parse {
 	my ($self, $user) = @_;
 
-	unless ($user =~ m/^\Q$SRSTAG$SRSSEP\E/oi) {
-		die "Reverse address does not start with $SRSTAG.";
+	unless ($user =~ s/$SRS0RE//oi) {
+		die "Reverse address does not match $SRS0RE.";
 	}
 
-	# The 5 here matches the number of fields we encoded above. If
+	# The 4 here matches the number of fields we encoded above. If
 	# there are more + signs, then they belong in senduser anyway.
-	my (undef, $hash, $timestamp, $sendhost, $senduser) =
-					split(qr/\Q$SRSSEP\E/, $user, 5);
+	my ($hash, $timestamp, $sendhost, $senduser) =
+					split(qr/\Q$SRSSEP\E/, $user, 4);
 	# Again, this must match as above.
 	unless ($self->hash_verify($hash,$timestamp,$sendhost,$senduser)) {
 		die "Invalid hash";
